.. fwdpy11 documentation master file, created by
   sphinx-quickstart on Mon Mar 20 12:22:19 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to fwdpy11's documentation!
===================================

Contents:

.. toctree::


.. toctree::
    :caption: Contents:

Examples
##########################################

.. toctree::

    examples/parallel_simulation
    examples/stateful_fitness
    examples/pickling
    examples/DataMatrix

Functions and classes
##########################################

.. toctree::
    :maxdepth: 2

.. automodule:: fwdpy11.fwdpy11_types
    :members:
    :show-inheritance:

.. automodule:: fwdpy11.fwdpp_types
    :members:
    :show-inheritance:

.. automodule:: fwdpy11.fitness
    :members:
    :show-inheritance:

.. automodule:: fwdpy11.trait_values
    :members:
    :show-inheritance:

.. automodule:: fwdpy11.sampling
    :members:
    :show-inheritance:

.. automodule:: fwdpy11.regions
    :members:
    :show-inheritance:

.. automodule:: fwdpy11.temporal_samplers
    :members:
    :show-inheritance:

.. automodule:: fwdpy11.wright_fisher
    :members:
    :show-inheritance:

.. automodule:: fwdpy11.wright_fisher_qtrait
    :members:
    :show-inheritance:

.. automodule:: fwdpy11.dev
    :members:
    :show-inheritance:

fwdpy11 C++ API
==================

This sections document's fwdpy11's C++ headers.


.. doxygenindex::
    :project: fwdpy11

fwdpp C++ API
==================

This section docuement's fwdpp's API.

.. doxygenindex::
    :project: fwdpp

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
